@@ -36,7 +36,7 @@ import logging
 from functools import wraps
 from django.core.exceptions import PermissionDenied
 from django.contrib.auth import REDIRECT_FIELD_NAME
-from django.db.models import Q
+
 from django.shortcuts import get_object_or_404
 from django.utils.decorators import available_attrs
 from django.utils import six
@@ -44,8 +44,7 @@ from django.utils.translation import ugettext_lazy as _
 
 from . import settings
 from .compat import is_authenticated, reverse
-from .models import (Charge, Plan, RoleDescription, Signature, Subscription,
-    get_broker)
+from .models import Charge, Plan, Signature, Subscription, get_broker
 from .utils import datetime_or_now, get_organization_model, get_role_model
 
 
@@ -183,51 +182,16 @@ def fail_active_roles(request):
     User with active roles only
     """
     role_model = get_role_model()
-    if not role_model.objects.filter(user=request.user).exists():
-        # Find an organization with a matching e-mail domain.
-        domain = request.user.email.split('@')[-1].lower()
-        organization_model = get_organization_model()
-        try:
-            organization = organization_model.objects.filter(
-                email__endswith=domain).get()
-            # Find a RoleDescription we can implicitely grant to the user.
-            try:
-                role_descr = RoleDescription.objects.filter(
-                    Q(organization__isnull=True) | Q(organization=organization),
-                    implicit_create_on_none=True).get()
-                # Create a granted role implicitely. We assume the user's
-                # identity (ex: email) was verified.
-                organization.add_role(request.user, role_descr,
-                    request_user=request.user)
-            except role_model.DoesNotExist:
-                LOGGER.debug("'%s' does not have a role on any profile but"
-                    " we cannot grant one implicitely because there is"
-                    " no role description that permits it.",
-                    request.user)
-            except role_model.MultipleObjectsReturned:
-                LOGGER.debug("'%s' does not have a role on any profile but"
-                    " we cannot grant one implicitely because we have"
-                    " multiple role description that permits it. Ambiguous.",
-                    request.user)
-        except organization_model.DoesNotExist:
-            LOGGER.debug("'%s' does not have a role on any profile but"
-                " we cannot grant one implicitely because there is"
-                " no profiles with @%s e-mail domain.",
-                request.user, domain)
-        except organization_model.MultipleObjectsReturned:
-            LOGGER.debug("'%s' does not have a role on any profile but"
-                " we cannot grant one implicitely because @%s is"
-                " ambiguous. Multiple profiles share that email domain.",
-                request.user, domain)
+    redirect_to = reverse('saas_user_product_list', args=(request.user,))
+    if request.path == redirect_to:
+        # Prevents URL redirect loops
+        return False
 
     if role_model.objects.filter(
             user=request.user, grant_key__isnull=False).exists():
         # We have some invites pending so let's first stop
         # by the user accessibles page.
-        redirect_to = reverse('saas_user_product_list', args=(request.user,))
-        if request.path != redirect_to:
-            # Prevents URL redirect loops
-            return redirect_to
+        return redirect_to
 
     return False
 
